@@ -1,7 +1,7 @@
 from datetime import datetime, timedelta
 
 
-class DBStore(object):
+class DBStore:
     def __init__(self, db, name="py4web_session"):
         self.__prerequisites__ = [db]
         Field = db.Field
